# Copyright (c) 2015-2016 by Farsight Security, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""An SRA or RAD client that watches SIE channels using the pyaxa wrappers
for libaxa to get AXA hits."""

import axa

import re


def parse_anomalies(texts):
    """Convenience function to make a list of axa_p_anom_t messages from a
    list of strings specifying anomalies.

    Args:
      texts (list): text SIE channel aliases or "all"

    Returns:
      list of axa.MsgAnom messages specifying the anomalies
    """

    anomalies = []
    next_tag = axa.TAG_NONE
    for anomaly in texts:
        next_tag = next_tag + 1
        m = re.match(r'(\d+)\s+(.+)', anomaly)
        if not m:
            raise axa.FatalError('missing tag in "-a {}"'.format(anomaly))
        anomalies.append(axa.MsgAnom(m.group(1), m.group(2)))

    return anomalies
